Rotation class

Constructors

Rotation.deg({double x = 0, double y = 0, double z = 0})
Rotation.radians({double x = 0, double y = 0, double z = 0})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → double
final
y → double
final
z → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override