ScaleAnimatedWidget class

Inheritance

Constructors

ScaleAnimatedWidget({Widget? child, Duration delay = const Duration(), Curve curve = Curves.linear, Duration duration = const Duration(seconds: 2), dynamic animationFinished(bool)?, bool enabled = false, List<double> values = const [0, 1]})
A scale animation using 2-* values
ScaleAnimatedWidget.tween({Duration duration = const Duration(milliseconds: 500), double scaleEnabled = 1, double scaleDisabled = 0, bool enabled = true, dynamic animationFinished(bool)?, Curve curve = Curves.linear, required Widget child})
An scale animation using 2 values : enabled - disabled

Properties

animationFinished → dynamic Function(bool)?
final
child → Widget?
final
curve → Curve
final
delay → Duration
final
duration → Duration
final
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → List<double>
no setter

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
isAnimationEqual(ScaleAnimatedWidget other) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited